Releases
========

0.0.3 (2013-09-16)
------------------
 * Add the AdaptorDateBootStrapField and AdaptorDateTimeBootStrapField
 * Customize the inplaceedit toolbar
 * Customize the file adaptor
 * Improvements in the fixtures of the testing project


0.0.2 (2013-09-10)
------------------

 * Set the variable INPLACEEDIT_EVENT in the settings to "click"
 * Fix typo errors in the README

0.0.1 (2013-09-06)
------------------

 * Initial version